@@ -33,6 +33,9 @@ class BaseSsdbSortedSet(BaseSsdb):
     def zdel(self, name: str, key: str):
         pass
 
+    def multi_zdel(self, name: str, keys: List[str]) -> bool:
+        pass
+
     def zclear(self, name: str):
         pass
 
@@ -61,11 +64,11 @@ class SsdbSortedSet(BaseSsdbSortedSet):
 
     def zrank(self, name: str, key: str) -> int:
         result = self.execute_command('zrank', name, key)
-        return int(result)
+        return int(result) if result is not None else None
 
     def zrrank(self, name: str, key: str) -> int:
         result = self.execute_command('zrrank', name, key)
-        return int(result)
+        return int(result) if result is not None else None
 
     def zrange(self, name: str, offset: int, size: int) -> List[Tuple[str, float]]:
         result = self.execute_command('zrange', name, offset, size)
@@ -97,5 +100,9 @@ class SsdbSortedSet(BaseSsdbSortedSet):
     def zdel(self, name: str, key: str):
         result = self.execute_command('zdel', name, key)
 
+    def multi_zdel(self, name: str, keys: List[str]) -> bool:
+        self.execute_command('multi_zdel', name, *keys)
+        return True
+
     def zclear(self, name: str):
         result = self.execute_command('zclear', name)
